@@ -48,6 +48,10 @@ enum
     COL_SESSION,
     COL_SEAT,
     COL_OWNER,
+    COL_DISK_WRITE_TOTAL,
+    COL_DISK_READ_TOTAL,
+    COL_DISK_WRITE_CURRENT,
+    COL_DISK_READ_CURRENT,
     COL_PRIORITY,
     COL_SURFACE,
     COL_POINTER,
